==> vue-date-table-2.21.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/date-table/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["changerange", "pick"],
  props: [].concat(props, ["cellClassName", "date", "defaultValue", "disabledDate", "firstDayOfWeek", "maxDate", "minDate", "rangeState", "selectionMode", "showWeekNumber", "value", "formatWeeks"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("table", {
    class: ["tiny-date-table", {
      "is-week-mode": _vm.selectionMode === "week"
    }],
    attrs: {
      "cellspacing": "0",
      "cellpadding": "0"
    },
    on: {
      "mousemove": function mousemove($event) {
        $event.stopPropagation();
        return _vm.handleMouseMove.apply(null, arguments);
      },
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.handleClick.apply(null, arguments);
      }
    }
  }, [_c("tbody", [_c("tr", {
    staticClass: "tiny-date-table__week"
  }, [_vm.showWeekNumber ? _c("th", [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.week")) + " ")]) : _vm._e(), _vm._l(_vm.state.weeks, function(weekDay, key) {
    return _c("th", {
      key
    }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.weeks." + weekDay)) + " ")]);
  })], 2), _vm._l(_vm.state.rows, function(row, key) {
    return _c("tr", {
      key,
      class: ["tiny-date-table__row", {
        current: _vm.isWeekActive(row[1])
      }]
    }, _vm._l(row, function(cellValue, key2) {
      return _c("td", {
        key: key2,
        class: _vm.getCellClasses(cellValue)
      }, [_c("div", [_c("span", [_vm._v(" " + _vm._s(cellValue.text) + " ")])])]);
    }), 0);
  })], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };

==> vue-date-table-2.24.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/date-table/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["changerange", "pick"],
  props: [].concat(props, ["cellClassName", "date", "defaultValue", "disabledDate", "firstDayOfWeek", "maxDate", "minDate", "rangeState", "selectionMode", "showWeekNumber", "value", "formatWeeks", "readonly"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("table", {
    class: ["tiny-date-table", {
      "is-week-mode": _vm.selectionMode === "week"
    }],
    attrs: {
      "cellspacing": "0",
      "cellpadding": "0"
    },
    on: {
      "mousemove": function mousemove($event) {
        $event.stopPropagation();
        return _vm.handleMouseMove.apply(null, arguments);
      },
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.handleClick.apply(null, arguments);
      }
    }
  }, [_c("tbody", [_c("tr", {
    staticClass: "tiny-date-table__week"
  }, [_vm.showWeekNumber ? _c("th", [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.week")) + " ")]) : _vm._e(), _vm._l(_vm.state.weeks, function(weekDay, key) {
    return _c("th", {
      key
    }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.weeks." + weekDay)) + " ")]);
  })], 2), _vm._l(_vm.state.rows, function(row, key) {
    return _c("tr", {
      key,
      class: ["tiny-date-table__row", {
        current: _vm.isWeekActive(row[1])
      }]
    }, _vm._l(row, function(cellValue, key2) {
      return _c("td", {
        key: key2,
        class: _vm.getCellClasses(cellValue)
      }, [_c("div", [_c("span", [_vm._v(" " + _vm._s(cellValue.text) + " ")])])]);
    }), 0);
  })], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
